@@ -1,7 +1,7 @@
 #encoding:utf-8
 
 import chardet
-from .core import Splitter,Keyword
+from .core import Splitter,KeywordSplitter
 from .route.mmseg import route
 
 def seg_text(text):
@@ -11,9 +11,7 @@ def seg_text(text):
     return [word for word in Splitter(text)]
 
 def keywords(text):
-    #制作关键词,联合单个字
     if not isinstance(text,unicode):
         encoding = chardet.detect(text)['encoding']
         text = unicode(text,encoding)
-    words = Keyword(text)
-    return set([word for word in words])
+    return [word for word in KeywordSplitter(text)]
\ No newline at end of file
