@@ -187,39 +187,63 @@ class Splitter(BaseSplitter):
         return chunks
 
 
-class Keyword(BaseSplitter):
-    
-    def __init__(self, text):
-        BaseSplitter.__init__(self, text)
-        self.text = text
-        self.pos = 0
-        self.length = len(text) 
-        self.terms_group = self.get_all_words()
-        self.group_length = len(self.terms_group)
-        self.iter_pos = 0
-
-    def get_all_words(self):
-        result = []
+class KeywordSplitter(BaseSplitter):  
+      
+    def __init__(self,text,route=route): 
+        BaseSplitter.__init__(self, text)  
+        self.route = route  
+              
+      
+    #得到下一个切割结果  
+    def __iter__(self):  
+        result = set()
         while self.pos < self.text_length:  
             if self.is_cjk_char(self.next_char()):
-                words = self.get_match_cjk_words()
-                result.append(words)
-                self.pos += 1
-            elif self.is_latin_char(self.next_char()):
+                for words in self.get_cjk_words():
+                    for word in words:
+                        if len(word) > 0:
+                            word = unicode(word)
+                            result.add(word)
+            else :  
                 word = self.get_latin_words() 
-                result.append([word,])
-            else:
-                self.pos += 1
-        self.pos = 0
-        return result
-
-    def __iter__(self):
-        for i in range(self.group_length):
-            self.iter_pos = i
-            words = self.terms_group[i]
-            words_length = len(words)#当前chunks
-            for j in range(words_length):
-                word = words[j]
-                if word.length > 1 or words_length == 1:
-                    yield unicode(word)
-        self.iter_pos = 0
+                if len(word) > 0:  
+                    result.add(word)
+        for word in result:
+            yield unicode(word)
+        raise StopIteration
+      
+    #切割出中文词，并且做处理，用上述4种方法  
+    def get_cjk_words(self):  
+        #应用规则过滤
+        chunks = self.create_chunks()
+          
+        #最后只有一种切割方法  
+        for chunk in chunks:
+            self.pos += chunk.total_word_length()  
+            yield chunk.words
+      
+    #三重循环来枚举切割方法，这里也可以运用递归来实现  
+    def create_chunks(self):  
+        chunks = []  
+        originalPos = self.pos  
+        words1 = self.get_match_cjk_words()  
+          
+        for word1 in words1:  
+            self.pos += len(word1)  
+            if self.pos < self.text_length:  
+                words2 = self.get_match_cjk_words()  
+                for word2 in words2:  
+                    self.pos += len(word2)  
+                    if self.pos < self.text_length:  
+                        words3 = self.get_match_cjk_words()  
+                        for word3 in words3:  
+                            chunk = Chunk(word1,word2,word3)  
+                            chunks.append(chunk)  
+                    elif self.pos == self.text_length: 
+                        chunks.append(Chunk(word1,word2))  
+                    self.pos -= len(word2)  
+            elif self.pos == self.text_length:
+                chunks.append(Chunk(word1))  
+            self.pos -= len(word1)  
+        self.pos = originalPos
+        return chunks
